<?php

/**
 * @file
 * Entity Workflow API documentation.
 */

/**
 * @defgroup workflow_transition_hooks Workflow Transition Hooks
 * @{
 * For workflows that are attached to a fieldable entity type by using the
 * 'entity_workflow_state' field type, two transition hooks are invoked,
 * allowing modules to react before and after the transition has been performed.
 * @}
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Acts before a workflow transition is performed.
 *
 * This hook is invoked before the new state is written to the storage.
 *
 * @param \Drupal\workflows\WorkflowInterface $workflow
 *   The workflow.
 * @param \Drupal\workflows\Transition $transition
 *   The transition.
 * @param \Drupal\Core\Entity\FieldableEntityInterface $entity
 *   The entity for which a workflow state is changed.
 * @param string $field_name
 *   THe name of the field to which the workflow is attached.
 * @param array $context
 *   An array containing additional information about the transition, as
 *   defined by the initiator of the transition.
 */
function hook_workflows_pre_transition(\Drupal\workflows\WorkflowInterface $workflow, \Drupal\workflows\Transition $transition, \Drupal\Core\Entity\FieldableEntityInterface $entity, $field_name, $context = []) {
  // @todo
}

/**
 * Acts after a workflow transition is performed.
 *
 * This hook is invoked after the new state is written to the storage.
 *
 * @param \Drupal\workflows\WorkflowInterface $workflow
 *   The workflow.
 * @param \Drupal\workflows\Transition $transition
 *   The transition.
 * @param \Drupal\Core\Entity\FieldableEntityInterface $entity
 *   The entity for which a workflow state is changed.
 * @param string $field_name
 *   THe name of the field to which the workflow is attached.
 * @param array $context
 *   An array containing additional information about the transition, as
 *   defined by the initiator of the transition.
 */
function hook_workflows_post_transition(\Drupal\workflows\WorkflowInterface $workflow, \Drupal\workflows\Transition $transition, \Drupal\Core\Entity\FieldableEntityInterface $entity, $field_name, $context = []) {
  // @todo
}

/**
 * Allows altering the configuration of entity workflow plugins.
 *
 * @param array $configuration
 *   The configuration of the entity workflow plugin.
 * @param string $plugin_id
 *   The entity workflow plugin ID.
 */
function hook_entity_workflow_type_alter(array &$configuration, $plugin_id) {
  if ($plugin_id === 'entity_workflow_test_content') {
    $configuration['default_transition_log'] = t('The entity has been edited in a workspace.');
  }
}

/**
 * Allows altering the workflow state label.
 *
 * @param string $label
 *   The current state label.
 * @param array $context
 *   An array of context data containing 'entity', 'state', and 'workspace'.
 *   Note that 'entity' and 'workspace' are optional contexts, and they might
 *   not be always populated, for example, when visiting the workflow edit UI.
 */
function hook_entity_workflow_state_label_alter(&$label, array $context) {
  if ($context['entity']->getEntityTypeId() === 'custom_entity') {
    $label = t('Custom label');
  }
}

/**
 * Allows giving access to the entity workflow tab.
 *
 * @param bool $access
 *   Whether or not to provide access. Will be FALSE by default unless changed
 *   by an alter.
 * @param \Drupal\workflows\WorkflowInterface $workflow
 *   The workflow configuration entity.
 * @param \Drupal\Core\Entity\EntityInterface $entity
 *   The entity.
 */
function hook_entity_workflow_has_bulk_workflow_alter(&$access, \Drupal\workflows\WorkflowInterface $workflow, \Drupal\Core\Entity\EntityInterface $entity) {
  $access = TRUE;
}

/**
 * Returns a list of entities that should be presented on the bulk workflow tab.
 *
 * @param \Drupal\workflows\WorkflowInterface $workflow
 *   The workflow configuration entity.
 * @param \Drupal\Core\Entity\EntityInterface $entity
 *   The entity.
 *
 * @return array
 *   An array of entities. The key for each entity MUST be $entity_type . '--' .
 *   $entity_id.
 */
function hook_entity_workflow_bulk_workflow_entities(\Drupal\workflows\WorkflowInterface $workflow, \Drupal\Core\Entity\EntityInterface $entity) {
  return [];
}

/**
 * @} End of "addtogroup hooks".
 */
