<?php

namespace Drupal\entity_workflow_workspace\EventSubscriber;

use Drupal\entity_workflow\Event\EntityWorkflowEvents;
use Drupal\entity_workflow\Event\InitiateTransitionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class EntityWorkflowWorkspaceEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events = [
      // We need a higher priority than
      // \Drupal\entity_workflow\EventSubscriber\EntityWorkflowEventSubscriber
      // so we can publish the workspace *before* initiating the workflow
      // transition.
      EntityWorkflowEvents::INITIATE_TRANSITION => ['onInitiateTransaction', 50],
    ];
    return $events;
  }

  /**
   * Applies the workflow transition
   *
   * @param \Drupal\entity_workflow\Event\InitiateTransitionEvent $event
   *   The initiate transition event.
   */
  public function onInitiateTransaction(InitiateTransitionEvent $event) {
    if ($event->getWorkflowId() === 'workspace') {
      /** @var \Drupal\workspaces\WorkspaceInterface $workspace */
      $workspace = $event->getEntity();

      if ($event->getTransitionId() === 'publish') {
        $workspace->publish();
        // @todo When the workspace publisher will invoke a post publish event,
        //   execute the workflow transition there and stop propagating this event.
      }

      if ($event->getTransitionId() === 'unpublish') {
        \Drupal::service('wse.workspace_reverter')->revert($workspace);
      }
    }
  }

}
