<?php

namespace Drupal\entity_workflow_workspace\Plugin\WorkflowType;

use Drupal\entity_workflow\WorkflowType\EntityWorkflowTypeBase;

/**
 * @WorkflowType(
 *   id = "entity_workflow_workspace",
 *   label = @Translation("Workspace"),
 * )
 */
class EntityWorkflowWorkspace extends EntityWorkflowTypeBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'entity_types' => [
        'workspace' => [],
      ],
      'default_state' => 'draft',
      'default_transition' => 'new_draft',
      'states' => wse_workspace_get_states(),
      'transitions' => [
        'new_draft' => [
          'label' => t('New draft'),
          'from' => [],
          'to' => 'draft',
          'weight' => 0,
        ],
        'submit_for_review' => [
          'label' => t('Submit for Review'),
          'from' => ['draft'],
          'to' => 'review',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 10,
        ],
        'back_to_draft' => [
          'label' => t('Back to Draft'),
          'from' => ['review'],
          'to' => 'draft',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 20,
        ],
        'publish' => [
          'label' => t('Publish'),
          'from' => ['review'],
          'to' => 'archived',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 100,
        ],
        'unpublish' => [
          'label' => t('Unpublish'),
          'from' => ['archived'],
          'to' => 'draft',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 110,
        ],
      ],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function getPermissions() {
    $perms = [];

    // Add generic permission to transition to any state.
    $perms['use all workspace transitions'] = [
      'title' => $this->t('%workflow workflow: Use all transitions', [
        '%workflow' => $this->label(),
      ]),
      'description' => $this->t('Allow the user to transition from any state to any state, as defined in the %workflow workflow.', [
        '%workflow' => $this->label(),
      ]),
    ];

    foreach ($this->getTransitions() as $transition) {
      $perms['use workspace transition ' . $transition->id()] = [
        'title' => $this->t('%workflow workflow: Use %transition transition', [
          '%workflow' => $this->label(),
          '%transition' => $transition->label(),
        ]),
        'description' => $this->t('Allow the user to use the %transition transition, as defined in the %workflow workflow.', [
          '%workflow' => $this->label(),
          '%transition' => $transition->label(),
        ]),
      ];
    }

    $perms['publish workspaces always'] = [
      'title' => $this->t('Can always publish workspaces.'),
      'description' => $this->t('Allows user to publish a workspace, ignoring its workflow.'),
    ];

    return $perms;
  }

}
