<?php

namespace Drupal\entity_workflow\Event;

use Drupal\Core\Entity\ContentEntityInterface;
use Symfony\Component\EventDispatcher\Event;

/**
 * Defines the initiate transition event.
 *
 * @see \Drupal\entity_workflow\Event\EntityWorkflowEvents
 */
class InitiateTransitionEvent extends Event {

  /**
   * @var \Drupal\Core\Entity\ContentEntityInterface
   */
  protected $entity;

  /**
   * @var string
   */
  protected $workflowId;

  /**
   * @var string
   */
  protected $transitionId;

  /**
   * @var string
   */
  protected $transitionLog;

  /**
   * @var array
   */
  protected $transitionContext;

  /**
   * Constructs a new InitiateTransitionEvent.
   */
  public function __construct(ContentEntityInterface $entity, $workflow_id, $transition_id, $log = '', $context = []) {
    $this->entity = $entity;
    $this->workflowId = $workflow_id;
    $this->transitionId = $transition_id;
    $this->transitionLog = $log;
    $this->transitionContext = $context;
  }

  /**
   * @return \Drupal\Core\Entity\ContentEntityInterface
   */
  public function getEntity() {
    return $this->entity;
  }

  /**
   * @return string
   */
  public function getWorkflowId() {
    return $this->workflowId;
  }

  /**
   * @return string
   */
  public function getTransitionId() {
    return $this->transitionId;
  }

  /**
   * @return string
   */
  public function getTransitionLog() {
    return $this->transitionLog;
  }

  /**
   * @return array
   */
  public function getTransitionContext() {
    return $this->transitionContext;
  }

}
